<?php

namespace Laravel\Laravel\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Laravel\Laravel\Http\Requests\AddadminRequest;
use Laravel\Laravel\Models\Addadmin;

/**
 * Admin web controller class.
 */
class AddadminWorkflowController extends BaseController
{

    /**
     * Workflow controller function for addadmin.
     *
     * @param Model   $addadmin
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AddadminRequest $request, Addadmin $addadmin, $step)
    {

        try {

            $addadmin->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('laravel::addadmin.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/addadmin/addadmin/' . $addadmin->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/addadmin/addadmin/' . $addadmin->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for addadmin.
     *
     * @param Model   $addadmin
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Addadmin $addadmin, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $addadmin->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('laravel::addadmin.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('laravel::admin.addadmin.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('laravel::admin.addadmin.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('laravel::admin.addadmin.message', $data)->render();

        }

    }
}
