<?php

namespace Laravel\Laravel\Providers;

use Illuminate\Support\ServiceProvider;

class LaravelServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'laravel');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'laravel');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerLaravel();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerLaravel()
    {
        $this->app->bind('laravel', function($app) {
            return new Laravel($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Laravel', 'Lavalite\Laravel\Facades\Laravel');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('laravel.laravel', function ($app) {
            return $this->app->make('Laravel\Laravel\Laravel');
        });

                // Bind Addadmin to repository
        $this->app->bind(
            'Laravel\Laravel\Interfaces\AddadminRepositoryInterface',
            \Laravel\Laravel\Repositories\Eloquent\AddadminRepository::class
        );

        $this->app->register(\Laravel\Laravel\Providers\AuthServiceProvider::class);
                $this->app->register(\Laravel\Laravel\Providers\EventServiceProvider::class);
        
        $this->app->register(\Laravel\Laravel\Providers\RouteServiceProvider::class);
                $this->app->register(\Laravel\Laravel\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and laravel's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/laravel.php', 'laravel'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeLaravel::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['laravel.laravel'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('laravel/laravel.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/laravel')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/laravel')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
