<?php

namespace Laravel\Laravel\Workflow;

use Laravel\Laravel\Models\Addadmin;
use Validator;

class AddadminValidator
{

    /**
     * Determine if the given addadmin is valid for complete status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function complete(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given addadmin is valid for verify status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function verify(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given addadmin is valid for approve status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function approve(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given addadmin is valid for publish status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function publish(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given addadmin is valid for archive status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function archive(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given addadmin is valid for unpublish status.
     *
     * @param Addadmin $addadmin
     *
     * @return bool / Validator
     */
    public function unpublish(Addadmin $addadmin)
    {
        return Validator::make($addadmin->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
